from typing import Any


def request_execution(python_bytecode: bytes, function_name: str) -> Any:
    ...

def load_privileged_plugin(plugin_path: str) -> None:
    ...

def invoke_method(object, method_name: str, *args) -> Any:
    ...



import configparser
import io
import pathlib
from contextlib import contextmanager
from typing import Generator


plugins: dict[str, dict]

class PluginInitContext:
    @property
    def config(self) -> configparser.ConfigParser:
        ...

    @property
    def data_folder(self) -> pathlib.Path:
        ...

    @contextmanager
    def open_resource(self, name: str) -> Generator[io.IOBase, None, None]:
        ...

    def extract_resource(self, name: str, replace: bool = False) -> None:
        ...



import configparser
import typing

from diamond_shovel.function.task import WorkerPool, TaskContext


class Event:
    ...

class DiamondShovelInitEvent(Event):
    config: configparser.ConfigParser
    daemon: bool
    ...

class WorkerPoolInitEvent(Event):
    pool: WorkerPool
    ...

class WorkerEvent(Event):
    plugin_name: str
    worker_name: str
    ...

class WorkerFinishEvent(WorkerEvent):
    error: Exception
    ...

class TaskEvent(Event):
    task_context: TaskContext
    ...

class TaskDispatchEvent(TaskEvent):
    ...

class TaskReadTriggerEvent(TaskEvent):
    key: str
    value: typing.Any

class TaskWriteTriggerEvent(TaskEvent):
    key: str
    value: typing.Any
    old_value: typing.Any

def register_event(init_ctx, evt_class, handler):
    ...

def call_event(evt):
    ...



import io
import pathlib
from contextlib import contextmanager
from typing import Generator


class BinaryManager:
    def get_data_path_by_name(self, name: str) -> pathlib.Path:
        ...

    def register_binary_path(self, name: str, path: pathlib.Path, out: pathlib.Path) -> None:
        ...

    async def execute_binary(self, name: str, cmd_args: list[str], timeout: int,
                       error_manage: bool = True, separate_output: bool = True, text: bool = True) \
            -> tuple[str | bytes, str | bytes]:
        ...

    def clear_outs_folder(self):
        ...

    def check_binary(self, name: str) -> bool:
        ...

    @contextmanager
    def open_file(self, name: str, file_name: str, mode: str='r') -> Generator[io.IOBase, None, None]:
        ...



import setuptools
import subprocess
import re


with open("README.md", "r") as fh:
    long_description = fh.read()

try:
    process = subprocess.Popen(["git", "describe", "--tags"], stdout=subprocess.PIPE)
    output = process.communicate()[0]
    version = output.decode("utf-8").strip()
    version_strict = re.match(r"^\d+\.\d+\.\d+$", version)
    if not version_strict:
        version = re.match(r"(\d+\.\d+\.\d+)-\d+-g\w+$", version).group(1)
except Exception as e:
    version = "0.0.0"

setuptools.setup(
    name="diamond-shovel-api",
    version=version,
    license="AGPL-3.0",
    author="Diamond Shovel Development Team",
    author_email="diamondshovel@cyberspike.top",
    description="A tool for asset scanning and vulnerability discovery, but plugin API part",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://www.cyberspike.top/tools/diamond_shovel",
    packages=setuptools.find_packages(),
    keywords=["api", "plugin", "diamond_shovel", "security"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: GNU Affero General Public License v3",
    ],
    python_requires='>=3.6',
    install_requires=[
        "kink",
        "pymongo",
        "flask",
        "requests",
        "geopy"
    ],
    tests_require=[
        "pytest",
        "pytest-cov",
    ]
)


from enum import Enum
from typing import Callable, Coroutine, Any, AsyncIterator

from diamond_shovel.plugins import PluginInitContext


class TaskContext:
    async def get_worker_result(self, plugin_name, worker_name):
        ...

    async def get_remaining_workers(self) -> list[str]:
        ...

    async def get(self, item):
        ...

    async def set(self, key, value):
        ...

    def collect(self, key: str, size: int = 10) -> AsyncIterator[Any]:
        ...

    def __getitem__(self, item):
        ...

    def __setitem__(self, key, value):
        ...

    def operate(self, key, func, *args, **kwargs):
        ...


class WorkerPool:
    def register_worker(self, plugin_ctx: PluginInitContext, worker: Callable[[TaskContext], Coroutine[Any, Any, Any]], nice: int = 0):
        ...

pools: dict[str, WorkerPool] = {}
